@@ -287,6 +287,7 @@ void found_new_tech(struct player *plr, int tech_found, bool was_discovery,
   assert(tech_is_available(plr, tech_found) || tech_found == A_FUTURE);
 
   plr->got_tech = TRUE;
+  plr->research.changed_from = -1;
   plr->research.techs_researched++;
   was_first = (game.global_advances[tech_found] == 0);
 
@@ -816,19 +817,13 @@ void handle_player_rates(struct player *pplayer,
 **************************************************************************/
 void handle_player_research(struct player *pplayer, int tech)
 {
-  choose_tech(pplayer, tech);
-  send_player_info(pplayer, pplayer);
-
-  /* Notify Team members.  Note that the the player may not necessarily
-   * be researching the tech that has been set: if there were enough
-   * research points then research will finish immediately and the
-   * player will start researching the "next" tech (probably A_NONE). */
+  /* choose_tech and send update for all players on the team. */
   players_iterate(aplayer) {
-    if (pplayer != aplayer
-	&& aplayer->research.researching != pplayer->research.researching
-       && pplayer->diplstates[aplayer->player_no].type == DS_TEAM
-       && aplayer->is_alive) {
-      handle_player_research(aplayer, pplayer->research.researching);
+    if (pplayer == aplayer
+	|| (pplayer->diplstates[aplayer->player_no].type == DS_TEAM
+	    && aplayer->is_alive)) {
+      choose_tech(aplayer, tech);
+      send_player_info(aplayer, aplayer);
     }
   } players_iterate_end;
 }
@@ -1434,7 +1429,9 @@ void send_player_info_c(struct player *src, struct conn_list *dest)
 	} else if (pconn->player) {
 	  /* Players (including regular observers) */
 	  package_player_info(pplayer, &info, pconn->player, INFO_MINIMUM);
-	} 
+	} else {
+	  package_player_info(pplayer, &info, NULL, INFO_MINIMUM);
+	}
 
         send_packet_player_info(pconn, &info);
       } conn_list_iterate_end;
@@ -1489,8 +1486,8 @@ static void package_player_common(struct player *plr,
   to plr, we send a little to players we are in contact with and almost
   nothing to everyone else.
 
- Note: if reciever is NULL and info < INFO_EMBASSY the info related to the
-       receiving player are not set correctly.
+  Receiver may be NULL in which cases dummy values are sent for some
+  fields.
 **************************************************************************/
 static void package_player_info(struct player *plr,
                                 struct packet_player_info *packet,
@@ -1500,8 +1497,12 @@ static void package_player_info(struct player *plr,
   int i;
   enum plr_info_level info_level;
 
-  info_level = player_info_level(plr, receiver);
-  if (info_level < min_info_level) {
+  if (receiver) {
+    info_level = player_info_level(plr, receiver);
+    if (info_level < min_info_level) {
+      info_level = min_info_level;
+    }
+  } else {
     info_level = min_info_level;
   }
 
@@ -1511,7 +1512,8 @@ static void package_player_info(struct player *plr,
   /* Send diplomatic status of the player to everyone they are in
    * contact with. */
   if (info_level >= INFO_EMBASSY
-      || receiver->diplstates[plr->player_no].contact_turns_left > 0) {
+      || (receiver
+	  && receiver->diplstates[plr->player_no].contact_turns_left > 0)) {
     packet->target_government = plr->target_government;
     packet->embassy = plr->embassy;
     packet->gives_shared_vision = plr->gives_shared_vision;
@@ -1556,7 +1558,8 @@ static void package_player_info(struct player *plr,
 
   /* Make absolutely sure - in case you lose your embassy! */
   if (info_level >= INFO_EMBASSY 
-      || pplayer_get_diplstate(plr, receiver)->type == DS_TEAM) {
+      || (receiver
+	  && pplayer_get_diplstate(plr, receiver)->type == DS_TEAM)) {
     packet->bulbs_last_turn = plr->research.bulbs_last_turn;
   } else {
     packet->bulbs_last_turn = 0;
@@ -1597,7 +1600,8 @@ static void package_player_info(struct player *plr,
   packet->inventions[A_NONE] = plr->research.inventions[A_NONE].state + '0';
 
   if (info_level >= INFO_FULL
-      || plr->diplstates[receiver->player_no].type == DS_TEAM) {
+      || (receiver
+	  && plr->diplstates[receiver->player_no].type == DS_TEAM)) {
     packet->tech_goal       = plr->ai.tech_goal;
   } else {
     packet->tech_goal       = A_UNSET;
